@@ -18,7 +18,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "BatchShader.h"
 #include "Body.h"
 #include "Screen.h"
-#include "Sprite.h"
+#include "image/Sprite.h"
 
 #include <cmath>
 
