@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef CATEGORY_TYPES_H_
-#define CATEGORY_TYPES_H_
+#pragma once
 
 enum class CategoryType : int {
 	SHIP,
@@ -22,7 +21,3 @@ enum class CategoryType : int {
 	OUTFIT,
 	SERIES
 };
-
-
-
-#endif
