@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef ES_COLOR_H_
-#define ES_COLOR_H_
+#pragma once
 
 
 
@@ -63,7 +62,3 @@ private:
 
 	bool isLoaded = false;
 };
-
-
-
-#endif
