@@ -7,11 +7,16 @@ Foundation, either version 3 of the License, or (at your option) any later versi
 
 Endless Sky is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "Dictionary.h"
 
+#include "StringInterner.h"
+
 #include <cstring>
 #include <mutex>
 #include <set>
@@ -28,14 +33,14 @@ namespace {
 		// At each step of the search, we know the key is in [low, high).
 		size_t low = 0;
 		size_t high = v.size();
-		
+
 		while(low != high)
 		{
 			size_t mid = (low + high) / 2;
 			int cmp = strcmp(key, v[mid].first);
 			if(!cmp)
 				return make_pair(mid, true);
-			
+
 			if(cmp < 0)
 				high = mid;
 			else
@@ -43,18 +48,6 @@ namespace {
 		}
 		return make_pair(low, false);
 	}
-	
-	// String interning: return a pointer to a character string that matches the
-	// given string but has static storage duration.
-	const char *Intern(const char *key)
-	{
-		static set<string> interned;
-		static mutex m;
-		
-		// Just in case this function is accessed from multiple threads:
-		lock_guard<mutex> lock(m);
-		return interned.insert(key).first->c_str();
-	}
 }
 
 
@@ -64,8 +57,8 @@ double &Dictionary::operator[](const char *key)
 	pair<size_t, bool> pos = Search(key, *this);
 	if(pos.second)
 		return data()[pos.first].second;
-	
-	return insert(begin() + pos.first, make_pair(Intern(key), 0.))->second;
+
+	return insert(begin() + pos.first, make_pair(StringInterner::Intern(key), 0.))->second;
 }
 
 
