@@ -54,6 +54,18 @@ void Gamerules::Load(const DataNode &node)
 			depreciationGracePeriod = max<int>(0, child.Value(1));
 		else if(key == "depreciation max age")
 			depreciationMaxAge = max<int>(0, child.Value(1));
+		else if(key == "disabled fighters avoid projectiles")
+		{
+			const string &value = child.Token(1);
+			if(value == "all")
+				fighterHitPolicy = FighterDodgePolicy::ALL;
+			else if(value == "none")
+				fighterHitPolicy = FighterDodgePolicy::NONE;
+			else if(value == "only player")
+				fighterHitPolicy = FighterDodgePolicy::ONLY_PLAYER;
+			else
+				child.PrintTrace("Skipping unrecognized value for gamerule:");
+		}
 		else
 			child.PrintTrace("Skipping unrecognized gamerule:");
 	}
@@ -121,3 +133,10 @@ int Gamerules::DepreciationMaxAge() const
 {
 	return depreciationMaxAge;
 }
+
+
+
+Gamerules::FighterDodgePolicy Gamerules::FightersHitWhenDisabled() const
+{
+	return fighterHitPolicy;
+}
