@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "Information.h"
 
-#include "Sprite.h"
+#include "image/Sprite.h"
 
 using namespace std;
 
@@ -138,7 +138,7 @@ bool Information::HasCondition(const string &condition) const
 	if(condition.front() == '!')
 		return !HasCondition(condition.substr(1));
 
-	return conditions.count(condition);
+	return conditions.contains(condition);
 }
 
 
