@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef JUMP_TYPES_H_
-#define JUMP_TYPES_H_
+#pragma once
 
 
 
@@ -24,7 +23,3 @@ enum class JumpType : int {
 	HYPERDRIVE,
 	JUMP_DRIVE,
 };
-
-
-
-#endif
