@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef LINE_SHADER_H_
-#define LINE_SHADER_H_
+#pragma once
 
 class Color;
 class Point;
@@ -26,11 +25,7 @@ class Point;
 class LineShader {
 public:
 	static void Init();
-	static void Draw(const Point &from, const Point &to, float width, const Color &color);
+	static void Draw(const Point &from, const Point &to, float width, const Color &color, bool roundCap = true);
 	static void DrawDashed(const Point &from, const Point &to, const Point &unit, float width, const Color &color,
-		double dashLength, double spaceLength);
+		double dashLength, double spaceLength, bool roundCap = true);
 };
-
-
-
-#endif
