@@ -42,8 +42,8 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Screen.h"
 #include "Ship.h"
 #include "ShipJumpNavigation.h"
-#include "Sprite.h"
-#include "SpriteSet.h"
+#include "image/Sprite.h"
+#include "image/SpriteSet.h"
 #include "SpriteShader.h"
 #include "StellarObject.h"
 #include "System.h"
@@ -88,7 +88,6 @@ namespace {
 	}
 }
 
-double MapDetailPanel::scroll = 0.;
 double MapDetailPanel::planetPanelHeight = 0.;
 
 
@@ -113,6 +112,8 @@ void MapDetailPanel::Step()
 {
 	MapPanel::Step();
 
+	scroll.Step();
+
 	if(selectedSystem != shownSystem)
 		GeneratePlanetCards(*selectedSystem);
 
@@ -139,9 +140,9 @@ void MapDetailPanel::Draw()
 
 
 
-double MapDetailPanel::GetScroll()
+double MapDetailPanel::GetScroll() const
 {
-	return scroll;
+	return scroll.AnimatedValue();
 }
 
 
@@ -159,6 +160,8 @@ bool MapDetailPanel::Hover(int x, int y)
 	isPlanetViewSelected = (x < Screen::Left() + planetCardInterface->GetValue("width")
 		&& y < Screen::Top() + PlanetPanelHeight());
 
+	scrollbar.Hover(x, y);
+
 	return isPlanetViewSelected ? true : MapPanel::Hover(x, y);
 }
 
@@ -166,9 +169,12 @@ bool MapDetailPanel::Hover(int x, int y)
 
 bool MapDetailPanel::Drag(double dx, double dy)
 {
+	if(scroll.Scrollable() && scrollbar.SyncDrag(scroll, dx, dy))
+		return true;
+
 	if(isPlanetViewSelected)
 	{
-		SetScroll(scroll - dy);
+		scroll.Scroll(-dy, 0);
 
 		return true;
 	}
@@ -181,7 +187,7 @@ bool MapDetailPanel::Scroll(double dx, double dy)
 {
 	if(isPlanetViewSelected)
 	{
-		SetScroll(scroll - dy * Preferences::ScrollSpeed());
+		scroll.Scroll(-dy * Preferences::ScrollSpeed());
 
 		return true;
 	}
@@ -205,7 +211,7 @@ bool MapDetailPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command
 	{
 		// Clear the selected planet, if any.
 		selectedPlanet = nullptr;
-		SetScroll(0.);
+		scroll.Set(0);
 		// Toggle to the next link connected to the "source" system. If the
 		// shift key is down, the source is the end of the travel plan; otherwise
 		// it is one step before the end.
@@ -287,7 +293,7 @@ bool MapDetailPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command
 					card.Select();
 					double space = card.AvailableSpace();
 					if(space < planetCardHeight)
-						scroll += (planetCardHeight - space);
+						scroll.Scroll(planetCardHeight - space);
 					break;
 				}
 				// We have this one selected, the next one will be selected instead.
@@ -301,7 +307,7 @@ bool MapDetailPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command
 			// If none/the last one are considered selected, it will select the first one from the list.
 			if(!selectNext && !planetCards.empty())
 			{
-				SetScroll(0.);
+				scroll.Set(0);
 				planetCards.front().Select();
 			}
 		}
@@ -330,14 +336,14 @@ bool MapDetailPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command
 					card.Select(false);
 					double space = previousCard->AvailableSpace();
 					if(space < planetCardHeight)
-						scroll -= (planetCardHeight - space);
+						scroll.Scroll(space - planetCardHeight);
 					break;
 				}
 				previousCard = &card;
 			}
 			if(!anySelected && !planetCards.empty())
 			{
-				SetScroll(maxScroll);
+				scroll.Set(scroll.MaxValue() - scroll.DisplaySize());
 				planetCards.back().Select();
 			}
 		}
@@ -352,11 +358,15 @@ bool MapDetailPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command
 
 bool MapDetailPanel::Click(int x, int y, int clicks)
 {
+	if(scroll.Scrollable() && scrollbar.SyncClick(scroll, x, y, clicks))
+		return true;
+
 	const Interface *planetCardInterface = GameData::Interfaces().Get("map planet card");
 	const double planetCardWidth = planetCardInterface->GetValue("width");
 	const Interface *mapInterface = GameData::Interfaces().Get("map detail panel");
 	const double arrowOffset = mapInterface->GetValue("arrow x offset");
 	const double planetCardHeight = MapPlanetCard::Height();
+
 	if(x < Screen::Left() + 160)
 	{
 		// The player clicked in the left-hand interface. This could be the system
@@ -378,40 +388,29 @@ bool MapDetailPanel::Click(int x, int y, int clicks)
 	}
 	if(y <= Screen::Top() + planetPanelHeight + 30 && x <= Screen::Left() + planetCardWidth + arrowOffset + 10)
 	{
-		if(maxScroll && x > Screen::Left() + planetCardWidth + arrowOffset - 10)
+		for(auto &card : planetCards)
 		{
-			// The arrows are of size 10.
-			const double arrowVerticalOffset = mapInterface->GetValue("arrow y offset") + 10.;
-			bool arrowUp = (y < Screen::Top() + arrowVerticalOffset);
-			bool arrowDown = (!arrowUp && y > Screen::Top() + planetPanelHeight - arrowVerticalOffset);
-			SetScroll(scroll + (arrowUp ? -planetCardHeight : arrowDown ? planetCardHeight : 0.));
-		}
-		else
-		{
-			for(auto &card : planetCards)
+			MapPlanetCard::ClickAction clickAction = card.Click(x, y, clicks);
+			if(clickAction == MapPlanetCard::ClickAction::GOTO_SHIPYARD)
 			{
-				MapPlanetCard::ClickAction clickAction = card.Click(x, y, clicks);
-				if(clickAction == MapPlanetCard::ClickAction::GOTO_SHIPYARD)
-				{
-					GetUI()->Pop(this);
-					GetUI()->Push(new MapShipyardPanel(*this, true));
-					break;
-				}
-				else if(clickAction == MapPlanetCard::ClickAction::GOTO_OUTFITTER)
-				{
-					GetUI()->Pop(this);
-					GetUI()->Push(new MapOutfitterPanel(*this, true));
-					break;
-				}
-				// Then this is the planet selected.
-				else if(clickAction != MapPlanetCard::ClickAction::NONE)
-				{
-					selectedPlanet = card.GetPlanet();
-					if(selectedPlanet && player.Flagship())
-						player.SetTravelDestination(selectedPlanet);
-					if(clickAction != MapPlanetCard::ClickAction::SELECTED)
-						SetCommodity(static_cast<int>(clickAction));
-				}
+				GetUI()->Pop(this);
+				GetUI()->Push(new MapShipyardPanel(*this, true));
+				break;
+			}
+			else if(clickAction == MapPlanetCard::ClickAction::GOTO_OUTFITTER)
+			{
+				GetUI()->Pop(this);
+				GetUI()->Push(new MapOutfitterPanel(*this, true));
+				break;
+			}
+			// Then this is the planet selected.
+			else if(clickAction != MapPlanetCard::ClickAction::NONE)
+			{
+				selectedPlanet = card.GetPlanet();
+				if(selectedPlanet && player.Flagship())
+					player.SetTravelDestination(selectedPlanet);
+				if(clickAction != MapPlanetCard::ClickAction::SELECTED)
+					SetCommodity(static_cast<int>(clickAction));
 			}
 		}
 		return true;
@@ -435,7 +434,7 @@ bool MapDetailPanel::Click(int x, int y, int clicks)
 				{
 					planetCard.Select(planetCard.GetPlanet() == selectedPlanet);
 					if(planetCard.IsSelected())
-						SetScroll(place * planetCardHeight);
+						scroll.Set(place * planetCardHeight);
 					++place;
 				}
 			}
@@ -490,7 +489,7 @@ void MapDetailPanel::GeneratePlanetCards(const System &system)
 	set<const Planet *> shown;
 
 	planetCards.clear();
-	SetScroll(0.);
+	scroll.Set(0);
 	unsigned number = 0;
 	MapPlanetCard::ResetSize();
 	for(const StellarObject &object : system.Objects())
@@ -499,10 +498,10 @@ void MapDetailPanel::GeneratePlanetCards(const System &system)
 			// The same "planet" may appear multiple times in one system,
 			// providing multiple landing and departure points (e.g. ringworlds).
 			const Planet *planet = object.GetPlanet();
-			if(planet->IsWormhole() || !planet->IsAccessible(player.Flagship()) || shown.count(planet))
+			if(planet->IsWormhole() || !planet->IsAccessible(player.Flagship()) || shown.contains(planet))
 				continue;
 
-			planetCards.emplace_back(object, number, player.HasVisited(*planet));
+			planetCards.emplace_back(object, number, player.HasVisited(*planet), this);
 			shown.insert(planet);
 			++number;
 		}
@@ -704,18 +703,16 @@ void MapDetailPanel::DrawInfo()
 	// Draw the basic information for visitable planets in this system.
 	if(canView && !planetCards.empty())
 	{
-		uiPoint.Y() -= GetScroll();
-		maxScroll = 0.;
+		uiPoint.Y() -= scroll.AnimatedValue();
 		for(auto &card : planetCards)
 		{
 			// Fit another planet, if we can, also give scrolling freedom to reach the planets at the end.
 			// This updates the location of the card so it needs to be called before AvailableSpace().
 			card.DrawIfFits(uiPoint);
 			uiPoint.Y() += planetCardHeight;
-
-			// Do this all of the time so we can scroll if an element is partially shown.
-			maxScroll += (planetCardHeight - card.AvailableSpace());
 		}
+		scroll.SetMaxValue(planetCards.size() * planetCardHeight);
+		scroll.SetDisplaySize(PlanetPanelHeight());
 
 		// Edges:
 		Point pos(Screen::Left(), Screen::Top());
@@ -728,16 +725,17 @@ void MapDetailPanel::DrawInfo()
 		Point rightOff(.5 * (size.X() + right->Width()) - 1, -right->Height() / 2.);
 		SpriteShader::Draw(right, edgePos + rightOff);
 
-		if(maxScroll)
+		if(scroll.Scrollable())
 		{
 			const double arrowOffsetX = mapInterface->GetValue("arrow x offset");
 			const double arrowOffsetY = mapInterface->GetValue("arrow y offset");
-			// Draw the pointers to go up and down by a planet at most.
-			PointerShader::Draw(Point(Screen::Left() + planetWidth + arrowOffsetX,
-				Screen::Top() + arrowOffsetY), Point(0., -1.), 10.f, 10.f, 5.f, scroll ? medium : dim);
-			PointerShader::Draw(Point(Screen::Left() + planetWidth + arrowOffsetX,
-				Screen::Top() - arrowOffsetY + planetPanelHeight), Point(0., 1.), 10.f, 10.f, 5.f,
-				(scroll < maxScroll) ? medium : dim);
+
+			Point top(Screen::Left() + planetWidth + arrowOffsetX,
+				Screen::Top() + arrowOffsetY);
+			Point bottom(Screen::Left() + planetWidth + arrowOffsetX,
+				Screen::Top() - arrowOffsetY + planetPanelHeight);
+
+			scrollbar.SyncDraw(scroll, top, bottom);
 		}
 	}
 
@@ -819,7 +817,7 @@ void MapDetailPanel::DrawInfo()
 		uiPoint.Y() += 20.;
 	}
 
-	if(selectedPlanet && !selectedPlanet->Description().empty()
+	if(selectedPlanet && !selectedPlanet->Description().IsEmptyFor(player.Conditions())
 			&& player.HasVisited(*selectedPlanet) && !selectedPlanet->IsWormhole())
 	{
 		static const int X_OFFSET = 240;
@@ -832,7 +830,7 @@ void MapDetailPanel::DrawInfo()
 		WrappedText text(font);
 		text.SetAlignment(Alignment::JUSTIFIED);
 		text.SetWrapWidth(WIDTH - 20);
-		text.Wrap(selectedPlanet->Description());
+		text.Wrap(selectedPlanet->Description().ToString(player.Conditions()));
 		text.Draw(Point(Screen::Right() - X_OFFSET - WIDTH, Screen::Top() + 20), medium);
 
 		selectedSystemOffset = -150;
@@ -976,12 +974,3 @@ void MapDetailPanel::SetCommodity(int index)
 	commodity = index;
 	player.SetMapColoring(commodity);
 }
-
-
-
-void MapDetailPanel::SetScroll(double newScroll)
-{
-	MapDetailPanel::scroll = max(0., newScroll);
-	if(scroll > maxScroll)
-		scroll = maxScroll;
-}
