@@ -13,13 +13,14 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef MAP_DETAIL_PANEL_H_
-#define MAP_DETAIL_PANEL_H_
+#pragma once
 
 #include "MapPanel.h"
 
 #include "MapPlanetCard.h"
 #include "Point.h"
+#include "ScrollBar.h"
+#include "ScrollVar.h"
 
 #include <map>
 #include <vector>
@@ -42,9 +43,9 @@ public:
 	virtual void Step() override;
 	virtual void Draw() override;
 
+	double GetScroll() const;
 
 public:
-	static double GetScroll();
 	static double PlanetPanelHeight();
 
 
@@ -69,8 +70,6 @@ private:
 
 	// Set the commodity coloring, and update the player info as well.
 	void SetCommodity(int index);
-	// Set the scroll, and make sure it does not become a negative value.
-	void SetScroll(double newScroll);
 
 
 private:
@@ -80,9 +79,8 @@ private:
 	// Which panel is being hovered over and should be affected by up and down keys.
 	bool isPlanetViewSelected = false;
 
-	// Maximum scrolling possible with the current amount of planets being displayed.
-	double maxScroll = 0.;
-	static double scroll;
+	ScrollVar<double> scroll;
+	ScrollBar scrollbar;
 
 	// Default display scaling for orbits within the currently displayed system.
 	double scale = .03;
@@ -95,7 +93,3 @@ private:
 	// Vector offsets from the center of the "orbits" UI.
 	std::map<const Planet *, Point> planets;
 };
-
-
-
-#endif
