@@ -40,11 +40,12 @@ namespace {
 
 
 
-MapPlanetCard::MapPlanetCard(const StellarObject &object, unsigned number, bool hasVisited)
-	: number(number), hasVisited(hasVisited), planetName(object.Name())
+MapPlanetCard::MapPlanetCard(const StellarObject &object, unsigned number, bool hasVisited,
+		const MapDetailPanel *parent)
+	: parent(parent), number(number), hasVisited(hasVisited), planetName(object.Name())
 {
 	planet = object.GetPlanet();
-	hasSpaceport = planet->HasSpaceport();
+	hasSpaceport = planet->HasServices();
 	hasShipyard = planet->HasShipyard();
 	hasOutfitter = planet->HasOutfitter();
 	governmentName = planet->GetGovernment()->GetName();
@@ -101,8 +102,6 @@ MapPlanetCard::ClickAction MapPlanetCard::Click(int x, int y, int clicks)
 		double relativeY = (y - yCoordinate);
 		if(relativeY > 0. && relativeY < AvailableSpace())
 		{
-			isSelected = true;
-
 			// The first category is the planet name and is not selectable.
 			if(x > Screen::Left() + planetIconMaxSize &&
 					relativeY > textStart + categorySize && relativeY < textStart + categorySize * (categories + hasGovernments))
@@ -295,7 +294,7 @@ void MapPlanetCard::Highlight(double availableSpace) const
 double MapPlanetCard::AvailableTopSpace() const
 {
 	const double height = Height();
-	return min(height, max(0., (number + 1) * height - MapDetailPanel::GetScroll()));
+	return min(height, max(0., (number + 1) * height - parent->GetScroll()));
 }
 
 
