@@ -13,9 +13,10 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef MISSION_ACTION_H_
-#define MISSION_ACTION_H_
+#pragma once
 
+#include "ConditionSet.h"
+#include "ConditionsStore.h"
 #include "Conversation.h"
 #include "ExclusiveItem.h"
 #include "GameAction.h"
@@ -23,8 +24,8 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Phrase.h"
 
 #include <map>
-#include <memory>
 #include <string>
+#include <vector>
 
 class DataNode;
 class DataWriter;
@@ -60,7 +61,8 @@ public:
 	// Check if this action can be completed right now. It cannot be completed
 	// if it takes away money or outfits that the player does not have, or should
 	// take place in a system that does not match the specified LocationFilter.
-	bool CanBeDone(const PlayerInfo &player, const std::shared_ptr<Ship> &boardingShip = nullptr) const;
+	// It can also not be done if the mission is failed, and teh trigger doesn't support it.
+	bool CanBeDone(const PlayerInfo &player, bool isFailed, const std::shared_ptr<Ship> &boardingShip = nullptr) const;
 	// Check if this action requires this ship to exist in order to ever be completed.
 	bool RequiresGiftedShip(const std::string &shipId) const;
 	// Perform this action. If a conversation is shown, the given destination
@@ -71,18 +73,44 @@ public:
 
 	// "Instantiate" this action by filling in the wildcard text for the actual
 	// destination, payment, cargo, etc.
-	MissionAction Instantiate(std::map<std::string, std::string> &subs,
+	MissionAction Instantiate(const ConditionsStore &store, std::map<std::string, std::string> &subs,
 		const System *origin, int jumps, int64_t payload) const;
 
 	int64_t Payment() const noexcept;
 
+
 private:
+	class MissionDialog {
+	public:
+		MissionDialog(const ExclusiveItem<Phrase> &);
+		MissionDialog(const std::string &);
+		MissionDialog(const DataNode &);
+
+
+		std::string dialogText;
+		ExclusiveItem<Phrase> dialogPhrase;
+		ConditionSet condition;
+	};
+
+
+private:
+	std::string CollapseDialog(const ConditionsStore *store, const std::map<std::string, std::string> *subs) const;
+
+
+private:
+	// Whether this action can be triggered after the mission has failed.
+	bool runsWhenFailed = false;
+
 	std::string trigger;
 	std::string system;
 	LocationFilter systemFilter;
 
+	// Dialog text of instantiated missions, or missions with pure-text dialog (no conditions or phrase blocks)
 	std::string dialogText;
-	ExclusiveItem<Phrase> dialogPhrase;
+
+	// Logic for creating dialog text. Only valid for missions read in from game data files.
+	std::vector<MissionDialog> dialog;
+
 	ExclusiveItem<Conversation> conversation;
 
 	// Outfits that are required to be owned (or not) for this action to be performable.
@@ -91,7 +119,3 @@ private:
 	// Tasks this mission action performs, such as modifying accounts, inventory, or conditions.
 	GameAction action;
 };
-
-
-
-#endif
