@@ -46,8 +46,8 @@ int64_t Mortgage::Maximum(int64_t annualRevenue, int creditScore, double current
 
 
 // Create a new mortgage of the given amount.
-Mortgage::Mortgage(int64_t principal, int creditScore, int term)
-	: type(creditScore <= 0 ? "Fine" : "Mortgage"),
+Mortgage::Mortgage(string type, int64_t principal, int creditScore, int term)
+	: type(std::move(type)),
 	principal(principal),
 	interest((600 - creditScore / 2) * .00001),
 	interestString("0." + to_string(600 - creditScore / 2) + "%"),
@@ -57,6 +57,20 @@ Mortgage::Mortgage(int64_t principal, int creditScore, int term)
 
 
 
+// Create a mortgage with a specific interest rate instead of using the player's
+// credit score. Due to how the class is set up, the interest rate must currently
+// be within the range [0, 1).
+Mortgage::Mortgage(string type, int64_t principal, double interest, int term)
+	: type(std::move(type)),
+	principal(principal),
+	interest(interest * .01),
+	interestString("0." + to_string(static_cast<int>(1000. * interest)) + "%"),
+	term(term)
+{
+}
+
+
+
 // Construct and Load() at the same time.
 Mortgage::Mortgage(const DataNode &node)
 {
@@ -138,7 +152,8 @@ int64_t Mortgage::PayExtra(int64_t amount)
 
 
 // The type is "Mortgage" if this is a mortgage you applied for from a bank,
-// and "Fine" if this is a fine imposed on you for illegal activities.
+// "Fine" if this is a fine imposed on you for illegal activities, and
+// "Debt" if this is debt given to you by a mission.
 const string &Mortgage::Type() const
 {
 	return type;
