@@ -13,19 +13,22 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef PANEL_H_
-#define PANEL_H_
+#pragma once
 
 #include "Rectangle.h"
 
 #include <functional>
 #include <list>
+#include <memory>
+#include <mutex>
 #include <string>
+#include <vector>
 
 #include <SDL2/SDL.h>
 
 class Command;
 class Point;
+class Sprite;
 class TestContext;
 class UI;
 
@@ -37,6 +40,11 @@ class UI;
 // default, a panel allows the panels under it to show through, but does not
 // allow them to receive any events that it does not know how to handle.
 class Panel {
+public:
+	// Draw a sprite repeatedly to make a vertical edge.
+	static void DrawEdgeSprite(const Sprite *edgeSprite, int posX);
+
+
 public:
 	// Make the destructor virtual just in case any derived class needs it.
 	virtual ~Panel() = default;
@@ -65,9 +73,6 @@ public:
 	// so, apply that zone's action and return true.
 	bool ZoneClick(const Point &point);
 
-	// Forward the given TestContext to the Engine under MainPanel.
-	virtual void SetTestContext(TestContext &testContext);
-
 	// Is fast-forward allowed to be on when this panel is on top of the GUI stack?
 	virtual bool AllowsFastForward() const noexcept;
 
@@ -93,6 +98,7 @@ protected:
 	void DrawBackdrop() const;
 
 	UI *GetUI() const noexcept;
+	void SetUI(UI *ui);
 
 	// This is not for overriding, but for calling KeyDown with only one or two
 	// arguments. In this form, the command is never set, so you can call this
@@ -107,6 +113,12 @@ protected:
 	// (or if force is set to true). Return true if the message was displayed.
 	bool DoHelp(const std::string &name, bool force = false) const;
 
+	// Add a child. Deferred until next frame.
+	void AddChild(const std::shared_ptr<Panel> &panel);
+	// Remove a child. Deferred until next frame.
+	void RemoveChild(const Panel *panel);
+	// Handle deferred add/remove child operations.
+	void AddOrRemove();
 
 private:
 	class Zone : public Rectangle {
@@ -119,9 +131,24 @@ private:
 		std::function<void()> fun;
 	};
 
+	// The UI class will not directly call the virtual methods, but will call
+	// these instead. These methods will recursively allow child panels to
+	// handle the event first, before calling the virtual method for the derived
+	// class to handle it.
+	bool DoKeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool isNewPress);
+	bool DoClick(int x, int y, int clicks);
+	bool DoRClick(int x, int y);
+	bool DoHover(int x, int y);
+	bool DoDrag(double dx, double dy);
+	bool DoRelease(int x, int y);
+	bool DoScroll(double dx, double dy);
 
-private:
-	void SetUI(UI *ui);
+	void DoDraw();
+
+	// Call a method on all the children in reverse order, and then on this
+	// object. Recursion stops as soon as any child returns true.
+	template<typename...FARGS, typename...ARGS>
+	bool EventVisit(bool(Panel::*f)(FARGS ...args), ARGS ...args);
 
 
 private:
@@ -133,9 +160,23 @@ private:
 
 	std::list<Zone> zones;
 
+	std::vector<std::shared_ptr<Panel>> children;
+	std::vector<std::shared_ptr<Panel>> childrenToAdd;
+	std::vector<const Panel *> childrenToRemove;
+
 	friend class UI;
 };
 
 
 
-#endif
+template<typename ...FARGS, typename ...ARGS>
+bool Panel::EventVisit(bool (Panel::*f)(FARGS ...), ARGS ...args)
+{
+	// Check if a child panel will consume this event first.
+	for(auto it = children.rbegin(); it != children.rend(); ++it)
+		if((*it)->EventVisit(f, args...))
+			return true;
+
+	// If none of our children handled this event, then it could be for us.
+	return (this->*f)(args...);
+}
