@@ -13,9 +13,9 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef PLANET_H_
-#define PLANET_H_
+#pragma once
 
+#include "Paragraphs.h"
 #include "Port.h"
 #include "Sale.h"
 
@@ -68,8 +68,8 @@ public:
 	void SetName(const std::string &name);
 	// Get the name used for this planet in the data files.
 	const std::string &TrueName() const;
-	// Get the planet's descriptive text.
-	const std::string &Description() const;
+	// Return the description text for the planet, but not the spaceport:
+	const Paragraphs &Description() const;
 	// Get the landscape sprite.
 	const Sprite *Landscape() const;
 	// Get the name of the ambient audio to play on this planet.
@@ -159,7 +159,7 @@ public:
 private:
 	bool isDefined = false;
 	std::string name;
-	std::string description;
+	Paragraphs description;
 	Port port;
 	const Sprite *landscape = nullptr;
 	std::string music;
@@ -197,7 +197,3 @@ private:
 	Wormhole *wormhole = nullptr;
 	std::vector<const System *> systems;
 };
-
-
-
-#endif
