@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "Preferences.h"
 
-#include "Audio.h"
+#include "audio/Audio.h"
 #include "DataFile.h"
 #include "DataNode.h"
 #include "DataWriter.h"
@@ -54,6 +54,9 @@ namespace {
 	const vector<string> VSYNC_SETTINGS = {"off", "on", "adaptive"};
 	int vsyncIndex = 1;
 
+	const vector<string> CAMERA_ACCELERATION_SETTINGS = {"off", "on", "reversed"};
+	int cameraAccelerationIndex = 1;
+
 	class OverlaySetting {
 	public:
 		OverlaySetting() = default;
@@ -151,6 +154,7 @@ void Preferences::Load()
 	// values for settings that are off by default.
 	settings["Landing zoom"] = true;
 	settings["Render motion blur"] = true;
+	settings["Cloaked ship outlines"] = true;
 	settings[FRUGAL_ESCORTS] = true;
 	settings[EXPEND_AMMO] = true;
 	settings["Damaged fighters retreat"] = true;
@@ -165,6 +169,7 @@ void Preferences::Load()
 	settings["Hide unexplored map regions"] = true;
 	settings["Turrets focus fire"] = true;
 	settings["Ship outlines in shops"] = true;
+	settings["Ship outlines in HUD"] = true;
 	settings["Extra fleet status messages"] = true;
 	settings["Target asteroid based on"] = true;
 
@@ -187,6 +192,8 @@ void Preferences::Load()
 			zoomIndex = max(0., node.Value(1));
 		else if(node.Token(0) == "vsync")
 			vsyncIndex = max<int>(0, min<int>(node.Value(1), VSYNC_SETTINGS.size() - 1));
+		else if(node.Token(0) == "camera acceleration")
+			cameraAccelerationIndex = max<int>(0, min<int>(node.Value(1), CAMERA_ACCELERATION_SETTINGS.size() - 1));
 		else if(node.Token(0) == "Show all status overlays")
 			statusOverlaySettings[OverlayType::ALL].SetState(node.Value(1));
 		else if(node.Token(0) == "Show flagship overlay")
@@ -264,6 +271,7 @@ void Preferences::Save()
 	out.Write("Flotsam collection", flotsamIndex);
 	out.Write("view zoom", zoomIndex);
 	out.Write("vsync", vsyncIndex);
+	out.Write("camera acceleration", cameraAccelerationIndex);
 	out.Write("date format", dateFormatIndex);
 	out.Write("Show all status overlays", statusOverlaySettings[OverlayType::ALL].ToInt());
 	out.Write("Show flagship overlay", statusOverlaySettings[OverlayType::FLAGSHIP].ToInt());
@@ -523,6 +531,27 @@ const string &Preferences::VSyncSetting()
 
 
 
+void Preferences::ToggleCameraAcceleration()
+{
+	cameraAccelerationIndex = (cameraAccelerationIndex + 1) % CAMERA_ACCELERATION_SETTINGS.size();
+}
+
+
+
+Preferences::CameraAccel Preferences::CameraAcceleration()
+{
+	return static_cast<CameraAccel>(cameraAccelerationIndex);
+}
+
+
+
+const string &Preferences::CameraAccelerationSetting()
+{
+	return CAMERA_ACCELERATION_SETTINGS[cameraAccelerationIndex];
+}
+
+
+
 void Preferences::CycleStatusOverlays(Preferences::OverlayType type)
 {
 	// Calling OverlaySetting::Increment when the state is ON_HIT will cycle to off.
@@ -604,7 +633,6 @@ const string &Preferences::AutoFireSetting()
 
 
 
-
 void Preferences::ToggleBoarding()
 {
 	int targetIndex = boardingIndex + 1;
