@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef PRINT_DATA_H_
-#define PRINT_DATA_H_
+#pragma once
 
 // A class containing methods used to print ship and outfit stats to the console.
 class PrintData {
@@ -23,5 +22,3 @@ public:
 	static void Print(const char *const *argv);
 	static void Help();
 };
-
-#endif
