@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef SALE_H_
-#define SALE_H_
+#pragma once
 
 #include "DataNode.h"
 #include "Set.h"
@@ -71,7 +70,3 @@ bool Sale<Item>::Has(const Item *item) const
 {
 	return this->count(item);
 }
-
-
-
-#endif
