@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef SAVED_GAME_H_
-#define SAVED_GAME_H_
+#pragma once
 
 #include <string>
 
@@ -63,7 +62,3 @@ private:
 	const Sprite *shipSprite = nullptr;
 	std::string shipName;
 };
-
-
-
-#endif
