@@ -136,7 +136,7 @@ pair<JumpType, double> ShipJumpNavigation::GetCheapestJumpType(const System *fro
 {
 	if(!from || !to)
 		return make_pair(JumpType::NONE, 0.);
-	bool linked = from->Links().count(to);
+	bool linked = from->Links().contains(to);
 	double hyperFuelNeeded = HyperdriveFuel();
 	// If these two systems are linked, or if the system we're jumping from has its own jump range,
 	// then use the cheapest jump drive available, which is mapped to a distance of 0.
@@ -160,7 +160,7 @@ bool ShipJumpNavigation::CanJump(const System *from, const System *to) const
 	if(!from || !to)
 		return false;
 
-	if(from->Links().count(to) && (hasHyperdrive || hasJumpDrive))
+	if(from->Links().contains(to) && (hasHyperdrive || hasJumpDrive))
 		return true;
 
 	if(!hasJumpDrive)
