@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef START_CONDITIONS_H_
-#define START_CONDITIONS_H_
+#pragma once
 
 #include "CoreStartData.h"
 
@@ -123,7 +122,3 @@ private:
 	ConditionSet toReveal;
 	ConditionSet toUnlock;
 };
-
-
-
-#endif
