@@ -14,8 +14,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef START_CONDITIONS_PANEL_H_
-#define START_CONDITIONS_PANEL_H_
+#pragma once
 
 #include "Panel.h"
 
@@ -90,7 +89,3 @@ private:
 	Rectangle entriesContainer;
 	Point entryTextPadding;
 };
-
-
-
-#endif
