@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef COMPARATORS_BY_NAME_H_
-#define COMPARATORS_BY_NAME_H_
+#pragma once
 
 
 
@@ -37,6 +36,3 @@ public:
 		return a->DisplayName() < b->DisplayName();
 	}
 };
-
-#endif
-
