@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef ES_TEXT_FONT_H_
-#define ES_TEXT_FONT_H_
+#pragma once
 
 #include "../Shader.h"
 
@@ -94,7 +93,3 @@ private:
 	int advance[GLYPHS * GLYPHS] = {};
 	int widthEllipses = 0;
 };
-
-
-
-#endif
