@@ -29,7 +29,7 @@ namespace {
 
 void FontSet::Add(const string &path, int size)
 {
-	if(!fonts.count(size))
+	if(!fonts.contains(size))
 		fonts[size].Load(path);
 }
 
