@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef ES_TEXT_FONT_SET_H_
-#define ES_TEXT_FONT_SET_H_
+#pragma once
 
 #include <string>
 
@@ -29,7 +28,3 @@ public:
 	static void Add(const std::string &path, int size);
 	static const Font &Get(int size);
 };
-
-
-
-#endif
