@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef ES_TEXT_TABLE_H_
-#define ES_TEXT_TABLE_H_
+#pragma once
 
 #include "../Color.h"
 #include "DisplayText.h"
@@ -137,7 +136,3 @@ private:
 
 	std::vector<Column> columns;
 };
-
-
-
-#endif
