@@ -149,6 +149,14 @@ int WrappedText::Height() const
 
 
 
+// Return the width of the longest line of the wrapped text.
+int WrappedText::LongestLineWidth() const
+{
+	return longestLineWidth;
+}
+
+
+
 // Draw the text.
 void WrappedText::Draw(const Point &topLeft, const Color &color) const
 {
@@ -205,6 +213,8 @@ void WrappedText::SetText(const char *it, size_t length)
 void WrappedText::Wrap()
 {
 	height = 0;
+	longestLineWidth = 0;
+
 	if(text.empty() || !font)
 		return;
 
@@ -313,6 +323,9 @@ void WrappedText::AdjustLine(size_t &lineBegin, int &lineWidth, bool isEnd)
 	int wordCount = static_cast<int>(words.size() - lineBegin);
 	int extraSpace = wrapWidth - lineWidth;
 
+	if(lineWidth > longestLineWidth)
+		longestLineWidth = lineWidth;
+
 	// Figure out how much space is left over. Depending on the alignment, we
 	// will add that space to the left, to the right, to both sides, or to the
 	// space in between the words. Exception: the last line of a "justified"
